@@ -16,6 +16,11 @@ def simple_sequence():
     return EncodedArray(np.array([1, 2, 2, 3], dtype=np.uint8) + 64, bnp.encodings.BaseEncoding)
 
 
+@pytest.fixture
+def ragged_string_list():
+    return ['a', 'ac', 'acg']
+
+
 def _test_sequence_repr(sequence):
     assert repr(sequence).replace("\n", "") == "EncodedArray([[65, 66] [66 67]])"
 
@@ -78,5 +83,12 @@ def test_encoded_array_list_to_raggedarray(simple_sequence):
     assert_encoded_raggedarray_equal(array_list, str_list)
                                 
 
+@pytest.mark.parametrize('dtype', [object, None])
+def test_object_array(ragged_string_list, dtype):
+    object_array = np.array(ragged_string_list, dtype=dtype)
+    encoded_array = as_encoded_array(object_array)
+    assert_encoded_raggedarray_equal(encoded_array, ragged_string_list)
+    
+
 if __name__ == "__main__":
     test_works_with_ragged()
